@@ -8,24 +8,7 @@ import sys
 sys.path.insert(0, op.join(op.dirname(__file__), ".."))
 from goatools.obo_parser import GODag
 from goatools.mapslim import mapslim
-
-
-# copied from find_enrichment.py
-# TODO: put this method into the library, copying is BAD practise
-def read_associations(assoc_fn):
-    assoc = {}
-    for row in open(assoc_fn):
-        atoms = row.split()
-        if len(atoms) == 2:
-            a, b = atoms
-        elif len(atoms) > 2 and row.count('\t') == 1:
-            a, b = row.split("\t")
-        else:
-            continue
-        b = set(b.split(";"))
-        assoc[a] = b
-
-    return assoc
+from goatools.associations import read_associations
 
 
 if __name__ == '__main__':
@@ -81,7 +64,7 @@ if __name__ == '__main__':
     # in case a single term is given as input:
     if opts.term:
         if opts.term not in go_dag:
-            print(("term %s not found!" % opts.term), file=sys.stderr)
+            sys.stderr.write(("term %s not found!\n" % opts.term))
             sys.exit(1)
         direct_anc, all_anc = mapslim(opts.term, go_dag, goslim_dag)
         # output either all or only direct slims, depending on user command
@@ -95,7 +78,7 @@ if __name__ == '__main__':
     if opts.ass_file_name:
         assert os.path.exists(opts.ass_file_name), ("file %s not found!"
                                                     % opts.ass_file_name)
-        assocs = read_associations(opts.ass_file_name)
+        assocs = read_associations(opts.ass_file_name, 'id2gos')
         for protein_product, go_terms in assocs.items():
             all_direct_anc = set()
             all_covered_anc = set()
